# Babel Tower

This is a Python package containing modules for many common NLP tasks, such as keyword extraction, translation,
sentiment analysis, language detection, finding similar text, etc.

## Development

Run `pip install -e .` from the top directory, then you can import modules from the `gps_babel_tower` package.

## Examples

Check out `examples` for examples of using the NLP modules.